summaryrefslogtreecommitdiff
path: root/src/redis-cli.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/redis-cli.c')
-rw-r--r--src/redis-cli.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/redis-cli.c b/src/redis-cli.c
index cbb41f3f1..85ca404fb 100644
--- a/src/redis-cli.c
+++ b/src/redis-cli.c
@@ -336,7 +336,7 @@ static void cliOutputGenericHelp(void) {
" \"help <tab>\" to get a list of possible help topics\n"
" \"quit\" to exit\n"
"\n"
- "To set redis-cli perferences:\n"
+ "To set redis-cli preferences:\n"
" \":set hints\" enable online hints\n"
" \":set nohints\" disable online hints\n"
"Set your preferences in ~/.redisclirc\n",
@@ -1222,7 +1222,7 @@ static sds *cliSplitArgs(char *line, int *argc) {
}
}
/* Set the CLI perferences. This function is invoked when an interactive
* ":command" is called, or when reading ~/.redisclirc file, in order to
* set user preferences. */
void cliSetPreferences(char **argv, int argc, int interactive) {
@@ -1222,7 +1222,7 @@ static sds *cliSplitArgs(char *line, int *argc) {
}
}
-/* Set the CLI perferences. This function is invoked when an interactive
+/* Set the CLI preferences. This function is invoked when an interactive
* ":command" is called, or when reading ~/.redisclirc file, in order to
* set user preferences. */